@@ -1,4 +1,4 @@
-## Copyright (C) 2010, 2011   Lukas F. Reichlin
+## Copyright (C) 2010, 2011, 2012   Lukas F. Reichlin
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: May 2010
-## Version: 0.2
+## Version: 0.3
 
 function a = inv (a)
 
@@ -34,9 +34,28 @@ function a = inv (a)
     a.x = -a.x / norm2;
     a.y = -a.y / norm2;
     a.z = -a.z / norm2;
+  elseif (issquare (a.w))
+    ## blockwise inversion, use recursion
+    ## the formula is well-known from linear algebra
+    n = rows (a);       # a is square
+    m1 = fix (n/2);
+    m2 = m1 + 1;
+
+    A = subsref (a, substruct ("()", {1:m1, 1:m1}));
+    B = subsref (a, substruct ("()", {1:m1, m2:n}));
+    C = subsref (a, substruct ("()", {m2:n, 1:m1}));
+    D = subsref (a, substruct ("()", {m2:n, m2:n}));
+
+    iA = inv (A);
+    iAB = iA * B;
+    CiA = C * iA;
+    X = inv (D - C * iAB);
+    Y = X * CiA;
+    
+    a = [iA + iAB*Y, -iAB*X;
+                 -Y,      X];
   else
-    ## TODO: quaternion arrays
-    error ("quaternion: inv: implemented for scalar quaternions only");
+    error ("quaternion: inv: require square matrices of quaternions");
   endif
 
 endfunction
