@@ -1,4 +1,4 @@
-## Copyright (C) 2010   Lukas F. Reichlin
+## Copyright (C) 2010, 2012   Lukas F. Reichlin
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,21 +18,17 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: May 2010
-## Version: 0.1
+## Version: 0.2
 
-function a = plus (a, b)
+function q = plus (varargin)
 
-  if (! isa (a, "quaternion"))
-    a = quaternion (a);
-  endif
+  tmp = cellfun (@quaternion, varargin);  # uniformoutput = true !
 
-  if (! isa (b, "quaternion"))
-    b = quaternion (b);
-  endif
+  w = plus (tmp.w);
+  x = plus (tmp.x);
+  y = plus (tmp.y);
+  z = plus (tmp.z);
 
-  a.w = a.w + b.w;
-  a.x = a.x + b.x;
-  a.y = a.y + b.y;
-  a.z = a.z + b.z;
+  q = quaternion (w, x, y, z);
 
 endfunction
